@@ -275,7 +275,7 @@ class Seti():
         data_read_cash = {"email": email,
                           "first_name": first_name,
                           "phone": phone,
-                          "iso_code": iso_code}
+                          "isoCode": iso_code}
         CREATE_USER_URL = "create-user"
         encode_data = self.sign_data(data_read_cash)
         return ResponseCreateUser(self.send_request(data_read_cash, encode_data, CREATE_USER_URL))
